# BioPy

Project developed in the scope of the Bioinformatics course at Polytechnic of Turin.
The task was to perform domain translation on multi-omics data using AutoEncoders and different datasets.

For a more extensive explanation on the contents and how to download datasets and replicate results; see our documentation at
`https://biopy-proj.readthedocs.io/en/latest/index.html`
